==> PS_INB_ERX_3.0.1.011.zip: PS_INB_ERX_Common/src/main/java/gov/va/med/pharmacy/wsclients/eAnde/MilitaryServiceSiteRecordCollection.java <==

package gov.va.med.pharmacy.wsclients.eAnde;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for militaryServiceSiteRecordCollection complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="militaryServiceSiteRecordCollection"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="militaryServiceSiteRecord" type="{http://URL/schemas}militaryServiceSiteRecordInfo" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "militaryServiceSiteRecordCollection", propOrder = {
    "militaryServiceSiteRecord"
})
public class MilitaryServiceSiteRecordCollection {

    @XmlElement(nillable = true)
    protected List<MilitaryServiceSiteRecordInfo> militaryServiceSiteRecord;

    /**
     * Gets the value of the militaryServiceSiteRecord property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the militaryServiceSiteRecord property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMilitaryServiceSiteRecord().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MilitaryServiceSiteRecordInfo }
     * 
     * 
     */
    public List<MilitaryServiceSiteRecordInfo> getMilitaryServiceSiteRecord() {
        if (militaryServiceSiteRecord == null) {
            militaryServiceSiteRecord = new ArrayList<MilitaryServiceSiteRecordInfo>();
        }
        return this.militaryServiceSiteRecord;
    }

}

==> PS_INB_ERX_3.0.5.003.zip: PS_INB_ERX_Common/src/main/java/gov/va/med/pharmacy/wsclients/eAnde/MilitaryServiceSiteRecordCollection.java <==

package gov.va.med.pharmacy.wsclients.eAnde;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for militaryServiceSiteRecordCollection complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="militaryServiceSiteRecordCollection"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="militaryServiceSiteRecord" type="{http://DNS.URL       /schemas}militaryServiceSiteRecordInfo" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "militaryServiceSiteRecordCollection", propOrder = {
    "militaryServiceSiteRecord"
})
public class MilitaryServiceSiteRecordCollection {

    @XmlElement(nillable = true)
    protected List<MilitaryServiceSiteRecordInfo> militaryServiceSiteRecord;

    /**
     * Gets the value of the militaryServiceSiteRecord property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the militaryServiceSiteRecord property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMilitaryServiceSiteRecord().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MilitaryServiceSiteRecordInfo }
     * 
     * 
     */
    public List<MilitaryServiceSiteRecordInfo> getMilitaryServiceSiteRecord() {
        if (militaryServiceSiteRecord == null) {
            militaryServiceSiteRecord = new ArrayList<MilitaryServiceSiteRecordInfo>();
        }
        return this.militaryServiceSiteRecord;
    }

}
